You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@hama.apache.org by ed...@apache.org on 2008/10/09 09:51:44 UTC

svn commit: r703093 - in /incubator/hama/trunk/src: examples/org/apache/hama/examples/MatrixAddition.java java/org/apache/hama/AbstractMatrix.java java/org/apache/hama/Matrix.java

Author: edwardyoon
Date: Thu Oct  9 00:51:44 2008
New Revision: 703093

URL: http://svn.apache.org/viewvc?rev=703093&view=rev
Log:
Rename clear to close.

Modified:
    incubator/hama/trunk/src/examples/org/apache/hama/examples/MatrixAddition.java
    incubator/hama/trunk/src/java/org/apache/hama/AbstractMatrix.java
    incubator/hama/trunk/src/java/org/apache/hama/Matrix.java

Modified: incubator/hama/trunk/src/examples/org/apache/hama/examples/MatrixAddition.java
URL: http://svn.apache.org/viewvc/incubator/hama/trunk/src/examples/org/apache/hama/examples/MatrixAddition.java?rev=703093&r1=703092&r2=703093&view=diff
==============================================================================
--- incubator/hama/trunk/src/examples/org/apache/hama/examples/MatrixAddition.java (original)
+++ incubator/hama/trunk/src/examples/org/apache/hama/examples/MatrixAddition.java Thu Oct  9 00:51:44 2008
@@ -49,6 +49,10 @@
     Matrix c = a.add(b);
 
     printMatrix("C = A + B", c);
+
+    a.close();
+    b.close();
+    c.close();
   }
 
   private static void parseArgs(String[] args) {

Modified: incubator/hama/trunk/src/java/org/apache/hama/AbstractMatrix.java
URL: http://svn.apache.org/viewvc/incubator/hama/trunk/src/java/org/apache/hama/AbstractMatrix.java?rev=703093&r1=703092&r2=703093&view=diff
==============================================================================
--- incubator/hama/trunk/src/java/org/apache/hama/AbstractMatrix.java (original)
+++ incubator/hama/trunk/src/java/org/apache/hama/AbstractMatrix.java Thu Oct  9 00:51:44 2008
@@ -152,7 +152,7 @@
     return (matrixName != null) ? matrixName : null;
   }
 
-  public void clear() throws IOException {
+  public void close() throws IOException {
     admin.deleteTable(matrixName);
   }
 

Modified: incubator/hama/trunk/src/java/org/apache/hama/Matrix.java
URL: http://svn.apache.org/viewvc/incubator/hama/trunk/src/java/org/apache/hama/Matrix.java?rev=703093&r1=703092&r2=703093&view=diff
==============================================================================
--- incubator/hama/trunk/src/java/org/apache/hama/Matrix.java (original)
+++ incubator/hama/trunk/src/java/org/apache/hama/Matrix.java Thu Oct  9 00:51:44 2008
@@ -249,9 +249,9 @@
   public void load(String path) throws IOException;
 
   /**
    * Clear current matrix.
    * 
    * @throws Exception
    */
-  public void clear() throws IOException;
+  public void close() throws IOException;
 }
@@ -249,9 +249,9 @@
 
   /**
-   * Clear current matrix.
+   * Close current matrix.
    * 
    * @throws Exception